OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Resursă",
    "Room" : "Sală",
    "Unknown" : "Necunoscut",
    "Required" : "Necesar",
    "Optional" : "Opțional",
    "Does not attend" : "Nu participă",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ești într-un fus orar necunoscut ({tz}), se revine la UTC",
    "Please create a calendar first." : "Creează un calendar mai întâi.",
    "New event" : "Eveniment nou",
    "Attendees" : "Participanți",
    "Reminders" : "Mementouri",
    "Repeating" : "Ciclic",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "Cancelled" : "Anulat",
    "Please add a title!" : "Adaugă un titlu!",
    "Please select a calendar!" : "Alege un calendar!",
    "Global" : "Global",
    "None" : "Niciuna",
    "Every day" : "În fiecare zi",
    "Every week" : "În fiecare săptămână",
    "Every month" : "În fiecare lună",
    "Every year" : "În fiecare an",
    "never" : "niciodată",
    "after" : "după",
    "At time of event" : "La începutul evenimentului",
    "5 minutes before" : "cu 5 minute înainte",
    "10 minutes before" : "cu 10 minute înainte",
    "15 minutes before" : "cu 15 minute înainte",
    "30 minutes before" : "cu 30 minute înainte",
    "1 hour before" : "cu o oră înainte",
    "2 hours before" : "cu 2 ore înainte",
    "Custom" : "Particularizat",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Pop up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "ore",
    "days" : "zile",
    "week" : "săptămână",
    "before" : "înainte",
    "start" : "început",
    "end" : "sfârșit",
    "Week {number} of {year}" : "Săptămâna {number} din {year}",
    "Successfully imported" : "Importat cu succes",
    "Partially imported, 1 failure" : "Importat parțial, o eroare",
    "Partially imported, {n} failures" : "Importat parțial, {n} erori",
    "Audio alarm" : "Alarmă audio",
    "Pop-up" : "Pop up",
    "E-Mail" : "Email",
    "{calendar} shared by {owner}" : "{calendar} partajat de {owner}",
    "Title of the Event" : "Numele evenimentului",
    "starts" : "începe",
    "ends" : "se termină",
    "All day Event" : "Toată ziua",
    "Delete" : "Șterge",
    "Cancel" : "Anulează",
    "More ..." : "Mai mult ...",
    "Create" : "Creează",
    "Update" : "Actualizare",
    "Close" : "Închide",
    "Location" : "Locație",
    "Description" : "Descriere",
    "Export" : "Exportă",
    "Day" : "Zi",
    "Week" : "Săptămâna",
    "Month" : "Luna",
    "Today" : "Astăzi",
    "Share Calendar" : "Partajează calendarul",
    "Shared" : "Partajat",
    "More" : "Mai mult",
    "Edit" : "Editează",
    "Link" : "Legătură",
    "Download" : "Descarcă",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "can edit" : "poate edita",
    "group" : "grup",
    "New Calendar" : "Calendar nou",
    "Subscriptions" : "Abonmente",
    "New Subscription" : "Abonament nou",
    "Url" : "URL",
    "Edit event" : "Modifica eveniment",
    "Delete Event" : "Șterge evenimentul",
    "Save Event" : "Salvează evenimentul",
    "Time" : "Timp",
    "Type" : "Tip",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Repetă",
    "times every" : "ori la fiecare",
    "Add" : "Adaugă",
    "E-Mail address of attendee" : "Adresa email a participantului",
    "from" : "de la",
    "to" : "către",
    "This event's repeating rule is not supported yet." : "Regula de repetare a acestui eveniment nu este încă suportată.",
    "Support for advanced rules will be added with subsequent updates." : "Suportul pentru reguli avansate va fi adăugat în actualizări viitoare.",
    "Reset repeating rule" : "Resetează regula pentru repetare",
    "Repeat every ..." : "Se repetă la fiecare ...",
    "end repeat ..." : "sfârșit repetare ...",
    "times" : "ori",
    "Import Calendars" : "Importă calendare",
    "Import canceled" : "Import anulat",
    "Analyzing calendar" : "Se analizează calendarul",
    "The file contains objects incompatible with the selected calendar" : "Fișierul conține obiecte incompatibile cu calendarul selectat",
    "New calendar" : "Calendar nou",
    "Import scheduled" : "Import programat",
    "Settings" : "Setări",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "Nu a fost selectat niciun calendar pentru import",
    "Primary CalDAV address" : "Adresă primară CalDAV",
    "iOS/OS X CalDAV address" : "Adresă iOS/OS X CalDAV"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
